Skip to content

Instantly share code, notes, and snippets.

View ddjerqq's full-sized avatar
🐙
말보다는 행동이지

Giorgi Nachkebia ddjerqq

🐙
말보다는 행동이지
View GitHub Profile
@ddjerqq
ddjerqq / hello.cu
Created January 8, 2023 15:39
hello CUDA application my first CUDA app
#include <iostream>
using namespace std;
// create a 'kernel'. a kernel is a function that runs on the 'device' - GPU
__global__
void saxpy(int n, float a, float* x, float* y)
{
// get the current index in the arrays;
int i = blockIdx.x * blockDim.x + threadIdx.x;
@ddjerqq
ddjerqq / julia.cu
Last active March 28, 2023 06:30
julia fractal set using CUDA and complex numbers
// check comments for where to find these headers
#include "../common/book.h"
#include "../common/cpu_bitmap.h"
#define DIM 1000
#define SCALE 0.1f
#define STEPS 300
#define JULIA_REAL (-0.8f)
#define JULIA_IMAG (0.155f)
@ddjerqq
ddjerqq / sha256.cuh
Last active August 9, 2024 19:02
CUDA C++ SHA256
#include <cstring>
#include <sstream>
#include <iomanip>
#ifndef SHA256_CUH
#define SHA256_CUH
#include <string>
#include <array>
@Softwave
Softwave / README.md
Last active November 27, 2025 14:05
Fibonacci Program

Fib

Simple fibonacci number calculator.

Usage: fib nth Fibonacci number

@ddjerqq
ddjerqq / Rfc6238.cs
Last active October 23, 2025 03:05
TOTP: Time-Based One-Time Password Algorithm Implementation in C#
using System.Security.Cryptography;
namespace Rfc6238;
public enum HmacAlgo
{
Sha1,
Sha256,
Sha512,
}
public static class ExpandoExt
{
/// <summary>
/// Add a property to a dynamic object at runtime.
/// </summary>
/// <example>
/// dynamic expando = new ExpandoObject();
/// expando.Name = "Brian";
/// expando.Country = "USA";
/// expando.AddProperty("Language", "English");